import { z } from 'zod';

/**
 * Schema for the main configuration object
 */
declare const ConfigSchema: z.ZodObject<{
    framework: z.ZodString;
    instance: z.ZodString;
    workspace: z.ZodObject<{
        id: z.ZodString;
        displayName: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        id: string;
        displayName: string;
    }, {
        id: string;
        displayName: string;
    }>;
    childWorkspace: z.ZodOptional<z.ZodObject<{
        id: z.ZodString;
        displayName: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        id: string;
        displayName: string;
    }, {
        id: string;
        displayName: string;
    }>>;
    defaultApplication: z.ZodObject<{
        id: z.ZodString;
        displayName: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        id: string;
        displayName: string;
    }, {
        id: string;
        displayName: string;
    }>;
    applications: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
        application: z.ZodObject<{
            id: z.ZodString;
            displayName: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            id: string;
            displayName: string;
        }, {
            id: string;
            displayName: string;
        }>;
        portalGql: z.ZodOptional<z.ZodString>;
        portalRest: z.ZodOptional<z.ZodString>;
        thegraphGql: z.ZodOptional<z.ZodString>;
        hasuraGql: z.ZodOptional<z.ZodString>;
        nodeJsonRpc: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        application: {
            id: string;
            displayName: string;
        };
        portalGql?: string | undefined;
        portalRest?: string | undefined;
        thegraphGql?: string | undefined;
        hasuraGql?: string | undefined;
        nodeJsonRpc?: string | undefined;
    }, {
        application: {
            id: string;
            displayName: string;
        };
        portalGql?: string | undefined;
        portalRest?: string | undefined;
        thegraphGql?: string | undefined;
        hasuraGql?: string | undefined;
        nodeJsonRpc?: string | undefined;
    }>>>;
}, "strip", z.ZodTypeAny, {
    framework: string;
    instance: string;
    workspace: {
        id: string;
        displayName: string;
    };
    defaultApplication: {
        id: string;
        displayName: string;
    };
    childWorkspace?: {
        id: string;
        displayName: string;
    } | undefined;
    applications?: Record<string, {
        application: {
            id: string;
            displayName: string;
        };
        portalGql?: string | undefined;
        portalRest?: string | undefined;
        thegraphGql?: string | undefined;
        hasuraGql?: string | undefined;
        nodeJsonRpc?: string | undefined;
    }> | undefined;
}, {
    framework: string;
    instance: string;
    workspace: {
        id: string;
        displayName: string;
    };
    defaultApplication: {
        id: string;
        displayName: string;
    };
    childWorkspace?: {
        id: string;
        displayName: string;
    } | undefined;
    applications?: Record<string, {
        application: {
            id: string;
            displayName: string;
        };
        portalGql?: string | undefined;
        portalRest?: string | undefined;
        thegraphGql?: string | undefined;
        hasuraGql?: string | undefined;
        nodeJsonRpc?: string | undefined;
    }> | undefined;
}>;
/**
 * Extended schema combining ConfigSchema with additional fields
 */
declare const ConfigEnvSchema: z.ZodObject<z.objectUtil.extendShape<{
    framework: z.ZodString;
    instance: z.ZodString;
    workspace: z.ZodObject<{
        id: z.ZodString;
        displayName: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        id: string;
        displayName: string;
    }, {
        id: string;
        displayName: string;
    }>;
    childWorkspace: z.ZodOptional<z.ZodObject<{
        id: z.ZodString;
        displayName: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        id: string;
        displayName: string;
    }, {
        id: string;
        displayName: string;
    }>>;
    defaultApplication: z.ZodObject<{
        id: z.ZodString;
        displayName: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        id: string;
        displayName: string;
    }, {
        id: string;
        displayName: string;
    }>;
    applications: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
        application: z.ZodObject<{
            id: z.ZodString;
            displayName: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            id: string;
            displayName: string;
        }, {
            id: string;
            displayName: string;
        }>;
        portalGql: z.ZodOptional<z.ZodString>;
        portalRest: z.ZodOptional<z.ZodString>;
        thegraphGql: z.ZodOptional<z.ZodString>;
        hasuraGql: z.ZodOptional<z.ZodString>;
        nodeJsonRpc: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        application: {
            id: string;
            displayName: string;
        };
        portalGql?: string | undefined;
        portalRest?: string | undefined;
        thegraphGql?: string | undefined;
        hasuraGql?: string | undefined;
        nodeJsonRpc?: string | undefined;
    }, {
        application: {
            id: string;
            displayName: string;
        };
        portalGql?: string | undefined;
        portalRest?: string | undefined;
        thegraphGql?: string | undefined;
        hasuraGql?: string | undefined;
        nodeJsonRpc?: string | undefined;
    }>>>;
}, {
    pat: z.ZodString;
    appUrl: z.ZodOptional<z.ZodString>;
    hasuraAdminSecret: z.ZodOptional<z.ZodString>;
    sessionSecret: z.ZodOptional<z.ZodString>;
}>, "strip", z.ZodTypeAny, {
    framework: string;
    instance: string;
    workspace: {
        id: string;
        displayName: string;
    };
    defaultApplication: {
        id: string;
        displayName: string;
    };
    pat: string;
    childWorkspace?: {
        id: string;
        displayName: string;
    } | undefined;
    applications?: Record<string, {
        application: {
            id: string;
            displayName: string;
        };
        portalGql?: string | undefined;
        portalRest?: string | undefined;
        thegraphGql?: string | undefined;
        hasuraGql?: string | undefined;
        nodeJsonRpc?: string | undefined;
    }> | undefined;
    appUrl?: string | undefined;
    hasuraAdminSecret?: string | undefined;
    sessionSecret?: string | undefined;
}, {
    framework: string;
    instance: string;
    workspace: {
        id: string;
        displayName: string;
    };
    defaultApplication: {
        id: string;
        displayName: string;
    };
    pat: string;
    childWorkspace?: {
        id: string;
        displayName: string;
    } | undefined;
    applications?: Record<string, {
        application: {
            id: string;
            displayName: string;
        };
        portalGql?: string | undefined;
        portalRest?: string | undefined;
        thegraphGql?: string | undefined;
        hasuraGql?: string | undefined;
        nodeJsonRpc?: string | undefined;
    }> | undefined;
    appUrl?: string | undefined;
    hasuraAdminSecret?: string | undefined;
    sessionSecret?: string | undefined;
}>;
/**
 * Schema for environment variables
 */
declare const EnvSchema: z.ZodObject<{
    SETTLEMINT_PAT_TOKEN: z.ZodString;
    SETTLEMINT_HASURA_GQL_ADMIN_SECRET: z.ZodOptional<z.ZodString>;
    NEXT_PUBLIC_SETTLEMINT_APP_URL: z.ZodOptional<z.ZodString>;
    SETTLEMINT_SESSION_SECRET: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    SETTLEMINT_PAT_TOKEN: string;
    SETTLEMINT_HASURA_GQL_ADMIN_SECRET?: string | undefined;
    NEXT_PUBLIC_SETTLEMINT_APP_URL?: string | undefined;
    SETTLEMINT_SESSION_SECRET?: string | undefined;
}, {
    SETTLEMINT_PAT_TOKEN: string;
    SETTLEMINT_HASURA_GQL_ADMIN_SECRET?: string | undefined;
    NEXT_PUBLIC_SETTLEMINT_APP_URL?: string | undefined;
    SETTLEMINT_SESSION_SECRET?: string | undefined;
}>;
declare const ApplicationConfigEnvSchema: z.ZodObject<z.objectUtil.extendShape<{
    application: z.ZodObject<{
        id: z.ZodString;
        displayName: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        id: string;
        displayName: string;
    }, {
        id: string;
        displayName: string;
    }>;
    portalGql: z.ZodOptional<z.ZodString>;
    portalRest: z.ZodOptional<z.ZodString>;
    thegraphGql: z.ZodOptional<z.ZodString>;
    hasuraGql: z.ZodOptional<z.ZodString>;
    nodeJsonRpc: z.ZodOptional<z.ZodString>;
}, {
    pat: z.ZodString;
    appUrl: z.ZodOptional<z.ZodString>;
    hasuraAdminSecret: z.ZodOptional<z.ZodString>;
}>, "strip", z.ZodTypeAny, {
    application: {
        id: string;
        displayName: string;
    };
    pat: string;
    portalGql?: string | undefined;
    portalRest?: string | undefined;
    thegraphGql?: string | undefined;
    hasuraGql?: string | undefined;
    nodeJsonRpc?: string | undefined;
    appUrl?: string | undefined;
    hasuraAdminSecret?: string | undefined;
}, {
    application: {
        id: string;
        displayName: string;
    };
    pat: string;
    portalGql?: string | undefined;
    portalRest?: string | undefined;
    thegraphGql?: string | undefined;
    hasuraGql?: string | undefined;
    nodeJsonRpc?: string | undefined;
    appUrl?: string | undefined;
    hasuraAdminSecret?: string | undefined;
}>;
type ConfigEnv = z.infer<typeof ConfigEnvSchema>;
type Config = z.infer<typeof ConfigSchema>;
type Env = z.infer<typeof EnvSchema>;
type ApplicationConfigEnv = z.infer<typeof ApplicationConfigEnvSchema>;
/**
 * Retrieves and parses the configuration, combining it with environment variables
 * @returns A promise that resolves to the parsed configuration or undefined if not found
 */
declare function config(): ConfigEnv | undefined;
/**
 * Creates or updates the configuration file
 * @param config The configuration object to be saved
 */
declare function createConfig(config: Config): Promise<void>;
/**
 * Creates or updates the .env.local file with the provided environment variables
 * @param env The environment variables to be saved
 */
declare function createEnv(env: Env): Promise<void>;
declare function activeConfig(): ApplicationConfigEnv | undefined;

export { type ApplicationConfigEnv, ApplicationConfigEnvSchema, type ConfigEnv, activeConfig, config, createConfig, createEnv };
